@@ -25,7 +25,12 @@ from text_alignment_tool.analyzers import (
 
 from text_alignment_tool.find_wordlist_for_alignment import find_wordlist_for_alignment
 
-from text_alignment_tool.shared_classes import LetterList, TextChunk
+from text_alignment_tool.shared_classes import (
+    LetterList,
+    TextChunk,
+    TextAlignments,
+    AlignmentKey,
+)
 
 from text_alignment_tool.text_loaders import (
     TextLoader,
